@@ -23,8 +23,8 @@ use crate::bls24479::ecp::ECP;
 use crate::bls24479::ecp4::ECP4;
 use crate::bls24479::fp::FP;
 use crate::bls24479::fp2::FP2;
-use crate::bls24479::fp24;
 use crate::bls24479::fp24::FP24;
+use crate::bls24479::fp24;
 use crate::bls24479::fp4::FP4;
 use crate::bls24479::fp8::FP8;
 use crate::bls24479::rom;
@@ -42,27 +42,28 @@ fn dbl(A: &mut ECP4, aa: &mut FP4, bb: &mut FP4, cc: &mut FP4) {
     bb.sqr(); //Z^2
 
     aa.dbl();
-    aa.neg();
-    aa.norm();
+    aa.neg(); aa.norm();
     aa.times_i();
 
     let sb = 3 * rom::CURVE_B_I;
     bb.imul(sb);
     cc.imul(3);
     if ecp::SEXTIC_TWIST == ecp::D_TYPE {
-        yy.times_i();
-        cc.times_i();
+	yy.times_i();
+	cc.times_i();
     }
     if ecp::SEXTIC_TWIST == ecp::M_TYPE {
-        bb.times_i();
+	bb.times_i();
     }
     bb.sub(&yy);
     bb.norm();
     A.dbl();
+
 }
 
 #[allow(non_snake_case)]
 fn add(A: &mut ECP4, B: &ECP4, aa: &mut FP4, bb: &mut FP4, cc: &mut FP4) {
+
     aa.copy(&A.getpx()); // X1
     cc.copy(&A.getpy()); // Y1
     let mut t1 = FP4::new_copy(&A.getpz()); // Z1
@@ -88,7 +89,7 @@ fn add(A: &mut ECP4, B: &ECP4, aa: &mut FP4, bb: &mut FP4, cc: &mut FP4) {
     bb.mul(&B.getpx()); // T2=(Y1-Z1.Y2).X2
     bb.sub(&t1);
     bb.norm(); // T2=(Y1-Z1.Y2).X2 - (X1-Z1.X2).Y2
-
+ 
     cc.neg();
     cc.norm(); // Y1=-(Y1-Z1.Y2).Xs
 
@@ -100,11 +101,11 @@ fn linedbl(A: &mut ECP4, qx: &FP, qy: &FP) -> FP24 {
     let mut a = FP8::new();
     let mut b = FP8::new();
     let mut c = FP8::new();
-    let mut aa = FP4::new();
-    let mut bb = FP4::new();
-    let mut cc = FP4::new();
+    let mut aa = FP4::new(); 
+    let mut bb = FP4::new(); 
+    let mut cc = FP4::new(); 
 
-    dbl(A, &mut aa, &mut bb, &mut cc);
+    dbl(A,&mut aa,&mut bb,&mut cc);
 
     cc.qmul(qx);
     aa.qmul(qy);
@@ -117,7 +118,7 @@ fn linedbl(A: &mut ECP4, qx: &FP, qy: &FP) -> FP24 {
         c.copy(&FP8::new_fp4(&cc));
         c.times_i();
     }
-    let mut res = FP24::new_fp8s(&a, &b, &c);
+    let mut res= FP24::new_fp8s(&a, &b, &c);
     res.settype(fp24::SPARSER);
     res
 }
@@ -127,11 +128,11 @@ fn lineadd(A: &mut ECP4, B: &ECP4, qx: &FP, qy: &FP) -> FP24 {
     let mut a = FP8::new();
     let mut b = FP8::new();
     let mut c = FP8::new();
-    let mut aa = FP4::new();
-    let mut bb = FP4::new();
+    let mut aa = FP4::new(); 
+    let mut bb = FP4::new(); 
     let mut cc = FP4::new();
-
-    add(A, B, &mut aa, &mut bb, &mut cc);
+    
+    add(A,B,&mut aa,&mut bb,&mut cc);
 
     cc.qmul(qx);
     aa.qmul(qy);
@@ -145,14 +146,14 @@ fn lineadd(A: &mut ECP4, B: &ECP4, qx: &FP, qy: &FP) -> FP24 {
         c.times_i();
     }
 
-    let mut res = FP24::new_fp8s(&a, &b, &c);
+    let mut res= FP24::new_fp8s(&a, &b, &c);
     res.settype(fp24::SPARSER);
     res
 }
 
 /* prepare ate parameter, n=6u+2 (BN) or n=u (BLS), n3=3*n */
 #[allow(non_snake_case)]
-fn lbits(n3: &mut BIG, n: &mut BIG) -> usize {
+fn lbits(n3: &mut BIG,n: &mut BIG) -> usize {
     n.copy(&BIG::new_ints(&rom::CURVE_BNX));
     n3.copy(&n);
     n3.pmul(3);
@@ -166,15 +167,15 @@ pub fn initmp() -> [FP24; ecp::ATE_BITS] {
 }
 
 /* basic Miller loop */
-pub fn miller(r: &mut [FP24]) -> FP24 {
-    let mut res = FP24::new_int(1);
+pub fn miller(r:&mut [FP24]) -> FP24 {
+    let mut res=FP24::new_int(1);
     for i in (1..ecp::ATE_BITS).rev() {
         res.sqr();
         res.ssmul(&r[i]);
-        r[i].zero();
+	r[i].zero();
     }
 
-    if ecp::SIGN_OF_X == ecp::NEGATIVEX {
+    if ecp::SIGN_OF_X==ecp::NEGATIVEX {
         res.conj();
     }
     res.ssmul(&r[0]);
@@ -182,50 +183,48 @@ pub fn miller(r: &mut [FP24]) -> FP24 {
     res
 }
 
-fn pack(aa: &FP4, bb: &FP4, cc: &FP4) -> FP8 {
-    let mut i = FP4::new_copy(cc);
+fn pack(aa: &FP4,bb: &FP4,cc: &FP4) -> FP8 {
+    let mut i=FP4::new_copy(cc);
     i.inverse(None);
-    let mut a = FP4::new_copy(aa);
-    let mut b = FP4::new_copy(bb);
+    let mut a=FP4::new_copy(aa);
+    let mut b=FP4::new_copy(bb);
     a.mul(&i);
     b.mul(&i);
-    FP8::new_fp4s(&a, &b)
+    FP8::new_fp4s(&a,&b)
 }
 
 fn unpack(t: &FP8, qx: &FP, qy: &FP) -> FP24 {
-    let b: FP8;
-    let mut c: FP8;
-    let w = FP4::new_fp(qx);
-
-    let mut aa = t.geta();
-    let bb = t.getb();
+    let b:FP8;
+    let mut c:FP8;
+    let w=FP4::new_fp(qx);
+ 
+    let mut aa=t.geta();
+    let bb=t.getb();
     aa.qmul(qy);
-    let a = FP8::new_fp4s(&aa, &bb);
+    let a=FP8::new_fp4s(&aa,&bb);
 
-    if ecp::SEXTIC_TWIST == ecp::D_TYPE {
-        b = FP8::new_fp4(&w);
-        c = FP8::new();
-    } else {
-        b = FP8::new();
-        c = FP8::new_fp4(&w);
-        c.times_i();
+    if ecp::SEXTIC_TWIST==ecp::D_TYPE {
+        b=FP8::new_fp4(&w);
+	c=FP8::new();
+    } else  {
+        b=FP8::new();
+	c=FP8::new_fp4(&w); c.times_i();
     }
-    let mut v = FP24::new_fp8s(&a, &b, &c);
+    let mut v=FP24::new_fp8s(&a,&b,&c);
     v.settype(fp24::SPARSEST);
     v
 }
 
 #[allow(non_snake_case)]
-pub fn precomp(T: &mut [FP8], GV: &ECP4) {
+pub fn precomp(T: &mut [FP8],GV: &ECP4) {
     let mut n = BIG::new();
     let mut n3 = BIG::new();
-    let nb = lbits(&mut n3, &mut n);
-    let mut aa = FP4::new();
-    let mut bb = FP4::new();
-    let mut cc = FP4::new();
+    let nb=lbits(&mut n3,&mut n);
+    let mut aa = FP4::new(); 
+    let mut bb = FP4::new(); 
+    let mut cc = FP4::new(); 
 
-    let mut P = ECP4::new();
-    P.copy(GV);
+    let mut P=ECP4::new(); P.copy(GV);
 
     let mut A = ECP4::new();
 
@@ -233,29 +232,26 @@ pub fn precomp(T: &mut [FP8], GV: &ECP4) {
     let mut NP = ECP4::new();
     NP.copy(&P);
     NP.neg();
-    let mut j = 0;
+    let mut j=0;
 
-    for i in (1..nb - 1).rev() {
-        dbl(&mut A, &mut aa, &mut bb, &mut cc);
-        T[j].copy(&pack(&aa, &bb, &cc));
-        j += 1;
-        let bt = n3.bit(i) - n.bit(i);
-        if bt == 1 {
-            add(&mut A, &P, &mut aa, &mut bb, &mut cc);
-            T[j].copy(&pack(&aa, &bb, &cc));
-            j += 1;
-        }
-        if bt == -1 {
-            add(&mut A, &NP, &mut aa, &mut bb, &mut cc);
-            T[j].copy(&pack(&aa, &bb, &cc));
-            j += 1;
-        }
+    for i in (1..nb-1).rev() {
+        dbl(&mut A,&mut aa,&mut bb,&mut cc);
+	T[j].copy(&pack(&aa,&bb,&cc)); j+=1;
+	let bt=n3.bit(i)-n.bit(i);
+	if bt==1 {
+	    add(&mut A,&P,&mut aa,&mut bb,&mut cc);
+	    T[j].copy(&pack(&aa,&bb,&cc)); j+=1;
+	}
+	if bt==-1 {
+	    add(&mut A,&NP,&mut aa,&mut bb,&mut cc);
+	    T[j].copy(&pack(&aa,&bb,&cc)); j+=1;
+	}
     }
 }
 
 /* Accumulate another set of line functions for n-pairing, assuming precomputation on G2 */
 #[allow(non_snake_case)]
-pub fn another_pc(r: &mut [FP24], T: &[FP8], QV: &ECP) {
+pub fn another_pc(r:&mut [FP24],T: &[FP8],QV: &ECP) {
     let mut n = BIG::new();
     let mut n3 = BIG::new();
 
@@ -263,7 +259,7 @@ pub fn another_pc(r: &mut [FP24], T: &[FP8], QV: &ECP) {
         return;
     }
 
-    let nb = lbits(&mut n3, &mut n);
+    let nb=lbits(&mut n3,&mut n);
 
     let mut Q = ECP::new();
     Q.copy(QV);
@@ -271,35 +267,33 @@ pub fn another_pc(r: &mut [FP24], T: &[FP8], QV: &ECP) {
     let qx = FP::new_copy(&Q.getpx());
     let qy = FP::new_copy(&Q.getpy());
 
-    let mut j = 0;
-    for i in (1..nb - 1).rev() {
-        let mut lv = unpack(&T[j], &qx, &qy);
-        j += 1;
-        let bt = n3.bit(i) - n.bit(i);
-        if bt == 1 {
-            let lv2 = unpack(&T[j], &qx, &qy);
-            j += 1;
-            lv.smul(&lv2);
-        }
-        if bt == -1 {
-            let lv2 = unpack(&T[j], &qx, &qy);
-            j += 1;
-            lv.smul(&lv2);
-        }
+    let mut j=0;
+    for i in (1..nb-1).rev() {
+        let mut lv=unpack(&T[j],&qx,&qy); j+=1;
+	let bt=n3.bit(i)-n.bit(i);
+	if bt==1 {
+	    let lv2=unpack(&T[j],&qx,&qy); j+=1;
+	    lv.smul(&lv2);
+	}
+	if bt==-1 {
+	    let lv2=unpack(&T[j],&qx,&qy); j+=1;
+	    lv.smul(&lv2);
+	}
         r[i].ssmul(&lv);
     }
 }
 
+
 /* Accumulate another set of line functions for n-pairing */
 #[allow(non_snake_case)]
-pub fn another(r: &mut [FP24], P1: &ECP4, Q1: &ECP) {
+pub fn another(r:&mut [FP24],P1: &ECP4,Q1: &ECP) {
     let mut n = BIG::new();
     let mut n3 = BIG::new();
-
+   
     if Q1.is_infinity() {
         return;
-    }
-    // P is needed in affine form for line function, Q for (Qx,Qy) extraction
+    }    
+// P is needed in affine form for line function, Q for (Qx,Qy) extraction
     let mut P = ECP4::new();
     P.copy(P1);
     P.affine();
@@ -316,18 +310,18 @@ pub fn another(r: &mut [FP24], P1: &ECP4, Q1: &ECP) {
     NP.copy(&P);
     NP.neg();
 
-    let nb = lbits(&mut n3, &mut n);
+    let nb=lbits(&mut n3,&mut n);
 
-    for i in (1..nb - 1).rev() {
-        let mut lv = linedbl(&mut A, &qx, &qy);
+    for i in (1..nb-1).rev() {
+        let mut lv=linedbl(&mut A,&qx,&qy);
 
-        let bt = n3.bit(i) - n.bit(i);
-        if bt == 1 {
-            let lv2 = lineadd(&mut A, &P, &qx, &qy);
+	let bt=n3.bit(i)-n.bit(i);
+        if bt==1 {
+            let lv2=lineadd(&mut A,&P,&qx,&qy);
             lv.smul(&lv2);
         }
-        if bt == -1 {
-            let lv2 = lineadd(&mut A, &NP, &qx, &qy);
+        if bt==-1 {
+            let lv2=lineadd(&mut A,&NP,&qx,&qy);
             lv.smul(&lv2);
         }
         r[i].ssmul(&lv);
@@ -362,7 +356,7 @@ pub fn ate(P1: &ECP4, Q1: &ECP) -> FP24 {
     NP.copy(&P);
     NP.neg();
 
-    let nb = lbits(&mut n3, &mut n);
+    let nb=lbits(&mut n3,&mut n);
 
     for i in (1..nb - 1).rev() {
         r.sqr();
@@ -395,10 +389,10 @@ pub fn ate2(P1: &ECP4, Q1: &ECP, R1: &ECP4, S1: &ECP) -> FP24 {
     let mut n3 = BIG::new();
 
     if Q1.is_infinity() {
-        return ate(R1, S1);
+        return ate(R1,S1);
     }
     if S1.is_infinity() {
-        return ate(P1, Q1);
+        return ate(P1,Q1);
     }
 
     let mut P = ECP4::new();
@@ -434,25 +428,25 @@ pub fn ate2(P1: &ECP4, Q1: &ECP, R1: &ECP4, S1: &ECP) -> FP24 {
     NR.copy(&R);
     NR.neg();
 
-    let nb = lbits(&mut n3, &mut n);
+    let nb=lbits(&mut n3,&mut n);
 
     for i in (1..nb - 1).rev() {
         r.sqr();
         let mut lv = linedbl(&mut A, &qx, &qy);
         let lv2 = linedbl(&mut B, &sx, &sy);
-        lv.smul(&lv2);
+	lv.smul(&lv2);
         r.ssmul(&lv);
         let bt = n3.bit(i) - n.bit(i);
         if bt == 1 {
             lv = lineadd(&mut A, &P, &qx, &qy);
             let lv2 = lineadd(&mut B, &R, &sx, &sy);
-            lv.smul(&lv2);
+	    lv.smul(&lv2);
             r.ssmul(&lv);
         }
         if bt == -1 {
             lv = lineadd(&mut A, &NP, &qx, &qy);
             let lv2 = lineadd(&mut B, &NR, &sx, &sy);
-            lv.smul(&lv2);
+	    lv.smul(&lv2);
             r.ssmul(&lv);
         }
     }
@@ -482,64 +476,61 @@ pub fn fexp(m: &FP24) -> FP24 {
 
     /* Hard part of final exp */
 
-    // See https://eprint.iacr.org/2020/875.pdf
-    let mut y1 = FP24::new_copy(&r);
-    y1.usqr();
-    y1.mul(&r); // y1=r^3
+// See https://eprint.iacr.org/2020/875.pdf
+        let mut y1 = FP24::new_copy(&r);
+        y1.usqr();
+        y1.mul(&r); // y1=r^3
 
-    let mut y0 = FP24::new_copy(&r.pow(&x));
-    if ecp::SIGN_OF_X == ecp::NEGATIVEX {
-        y0.conj();
-    }
-    let mut t0 = FP24::new_copy(&r);
-    t0.conj();
-    r.copy(&y0);
-    r.mul(&t0);
+        let mut y0 = FP24::new_copy(&r.pow(&x));
+        if ecp::SIGN_OF_X == ecp::NEGATIVEX {
+            y0.conj();
+        }
+        let mut t0 = FP24::new_copy(&r); t0.conj();
+        r.copy(&y0);
+        r.mul(&t0);
 
-    y0.copy(&r.pow(&x));
-    if ecp::SIGN_OF_X == ecp::NEGATIVEX {
-        y0.conj();
-    }
-    t0.copy(&r);
-    t0.conj();
-    r.copy(&y0);
-    r.mul(&t0);
+        y0.copy(&r.pow(&x));
+        if ecp::SIGN_OF_X == ecp::NEGATIVEX {
+            y0.conj();
+        }
+        t0.copy(&r); t0.conj();
+        r.copy(&y0);
+        r.mul(&t0);
 
-    // ^(x+p)
-    y0.copy(&r.pow(&x));
-    if ecp::SIGN_OF_X == ecp::NEGATIVEX {
-        y0.conj();
-    }
-    t0.copy(&r);
-    t0.frob(&f, 1);
-    r.copy(&y0);
-    r.mul(&t0);
+// ^(x+p)
+        y0.copy(&r.pow(&x));
+        if ecp::SIGN_OF_X == ecp::NEGATIVEX {
+            y0.conj();
+        }
+        t0.copy(&r);
+        t0.frob(&f,1);
+        r.copy(&y0);
+        r.mul(&t0);
 
-    // ^(x^2+p^2)
-    y0.copy(&r.pow(&x));
-    y0.copy(&y0.pow(&x));
-    t0.copy(&r);
-    t0.frob(&f, 2);
-    r.copy(&y0);
-    r.mul(&t0);
+// ^(x^2+p^2)
+        y0.copy(&r.pow(&x));
+        y0.copy(&y0.pow(&x));
+        t0.copy(&r);
+        t0.frob(&f,2); 
+        r.copy(&y0);
+        r.mul(&t0);
 
-    // ^(x^4+p^4-1)
-    y0.copy(&r.pow(&x));
-    y0.copy(&y0.pow(&x));
-    y0.copy(&y0.pow(&x));
-    y0.copy(&y0.pow(&x));
-    t0.copy(&r);
-    t0.frob(&f, 4);
-    y0.mul(&t0);
-    t0.copy(&r);
-    t0.conj();
-    r.copy(&y0);
-    r.mul(&t0);
+// ^(x^4+p^4-1)
+        y0.copy(&r.pow(&x));
+        y0.copy(&y0.pow(&x));
+        y0.copy(&y0.pow(&x));
+        y0.copy(&y0.pow(&x));
+        t0.copy(&r);
+        t0.frob(&f,4);
+        y0.mul(&t0);
+        t0.copy(&r); t0.conj();
+        r.copy(&y0);
+        r.mul(&t0);
 
-    r.mul(&y1);
-    r.reduce();
+        r.mul(&y1);
+        r.reduce();
 
-    /*
+/*    
     // Ghamman & Fouotsa Method
 
     let mut t7 = FP24::new_copy(&r);
@@ -806,7 +797,7 @@ pub fn g1member(P: &ECP) -> bool {
     if P.is_infinity() {
         return false;
     }
-    let W = g1mul(&P, &q);
+    let W=g1mul(&P,&q);
     if !W.is_infinity() {
         return false;
     }
@@ -820,7 +811,7 @@ pub fn g2member(P: &ECP4) -> bool {
     if P.is_infinity() {
         return false;
     }
-    let W = g2mul(&P, &q);
+    let W=g2mul(&P,&q);
     if !W.is_infinity() {
         return false;
     }
@@ -840,19 +831,18 @@ pub fn gtmember(m: &FP24) -> bool {
         return false;
     }
     let f = FP2::new_bigs(&BIG::new_ints(&rom::FRA), &BIG::new_ints(&rom::FRB));
-    r.copy(&m);
-    r.frob(&f, 4);
-    let mut w = FP24::new_copy(&r);
-    w.frob(&f, 4);
+    r.copy(&m); r.frob(&f,4);
+    let mut w = FP24::new_copy(&r); w.frob(&f,4); 
     w.mul(&m);
     if !w.equals(&r) {
         return false;
     }
     let q = BIG::new_ints(&rom::CURVE_ORDER);
     w.copy(&m);
-    r.copy(&gtpow(&w, &q));
+    r.copy(&gtpow(&w,&q));
     if !r.isunity() {
         return false;
     }
     true
 }
+
