@@ -22,8 +22,8 @@ use crate::arch::Chunk;
 
 use crate::arch::DChunk;
 
-use crate::fp256bn::dbig::DBIG;
 use crate::rand::RAND;
+use crate::fp256bn::dbig::DBIG;
 
 pub const MODBYTES: usize = 32;
 pub const BASEBITS: usize = 56;
@@ -126,7 +126,7 @@ impl BIG {
         for i in 0..NLEN {
             d |= self.w[i];
         }
-        (1 & ((d - 1) >> BASEBITS)) != 0
+        (1 & ((d-1)>>BASEBITS)) != 0
     }
 
     /* set to zero */
@@ -142,7 +142,7 @@ impl BIG {
         for i in 1..NLEN {
             d |= self.w[i];
         }
-        (1 & ((d - 1) >> BASEBITS) & (((self.w[0] ^ 1) - 1) >> BASEBITS)) != 0
+        (1 & ((d-1)>>BASEBITS) & (((self.w[0]^1)-1)>>BASEBITS)) != 0
     }
 
     /* set to one */
@@ -176,7 +176,7 @@ impl BIG {
 
     /* normalise BIG - force all digits < 2^BASEBITS */
     pub fn norm(&mut self) -> Chunk {
-        let mut carry = self.w[0] >> BASEBITS;
+        let mut carry = self.w[0]>>BASEBITS;
         self.w[0] &= BMASK;
         for i in 1..NLEN - 1 {
             let d = self.w[i] + carry;
@@ -279,7 +279,7 @@ impl BIG {
     }
 
     /* Convert to Hex String */
-    #[cfg(feature = "std")]
+#[cfg(feature = "std")]
     pub fn tostring(&self) -> String {
         let mut s = String::new();
         let mut len = self.nbits();
@@ -303,7 +303,7 @@ impl BIG {
         s
     }
 
-    #[cfg(feature = "std")]
+#[cfg(feature = "std")]
     pub fn fromstring(val: String) -> BIG {
         let mut res = BIG::new();
         let len = val.len();
@@ -312,7 +312,7 @@ impl BIG {
         res.w[0] += n as Chunk;
         for i in 1..len {
             res.shl(4);
-            let op = &val[i..i + 1];
+            let op = &val[i..i+1];
             let n = u8::from_str_radix(op, 16).unwrap();
             res.w[0] += n as Chunk;
         }
@@ -415,7 +415,7 @@ impl BIG {
     }
 
     pub fn frombytes(b: &[u8]) -> BIG {
-        BIG::frombytearray(b, 0)
+       BIG::frombytearray(b, 0)
     }
 
     /* self*=x, where x is >NEXCESS */
@@ -477,10 +477,10 @@ impl BIG {
         let mut gt = 0 as Chunk;
         let mut eq = 1 as Chunk;
         for i in (0..NLEN).rev() {
-            gt |= ((b.w[i] - a.w[i]) >> BASEBITS) & eq;
-            eq &= ((b.w[i] ^ a.w[i]) - 1) >> BASEBITS;
+ 		    gt |= ((b.w[i]-a.w[i]) >> BASEBITS) & eq;
+		    eq &= ((b.w[i]^a.w[i])-1) >> BASEBITS;
         }
-        (gt + gt + eq - 1) as isize
+        (gt+gt+eq-1) as isize
     }
 
     /* set x = x mod 2^m */
@@ -703,13 +703,13 @@ impl BIG {
         d.dmod(q)
     }
 
-    /* create randum BIG less than r and less than trunc bits */
+/* create randum BIG less than r and less than trunc bits */
     pub fn randtrunc(q: &BIG, trunc: usize, rng: &mut impl RAND) -> BIG {
-        let mut m = BIG::randomnum(q, rng);
-        if q.nbits() > trunc {
-            m.mod2m(trunc);
-        }
-        m
+        let mut m=BIG::randomnum(q,rng);
+	    if q.nbits() > trunc {
+	        m.mod2m(trunc);
+	    }
+	    m
     }
 
     /* Jacobi Symbol (this/p). Returns 0, 1 or -1 */
@@ -759,9 +759,7 @@ impl BIG {
     /* self=1/self mod p. Binary method */
     pub fn invmodp(&mut self, p: &BIG) {
         self.rmod(p);
-        if self.iszilch() {
-            return;
-        }
+	    if self.iszilch() {return;}
         let mut u = BIG::new_copy(self);
         let mut v = BIG::new_copy(p);
         let mut x1 = BIG::new_int(1);
@@ -774,7 +772,7 @@ impl BIG {
                 u.fshr(1);
                 t.copy(&x1);
                 t.add(p);
-                x1.cmove(&t, x1.parity());
+                x1.cmove(&t,x1.parity());
                 x1.norm();
                 x1.fshr(1);
             }
@@ -782,7 +780,7 @@ impl BIG {
                 v.fshr(1);
                 t.copy(&x2);
                 t.add(p);
-                x2.cmove(&t, x2.parity());
+                x2.cmove(&t,x2.parity());
                 x2.norm();
                 x2.fshr(1);
             }
@@ -791,7 +789,7 @@ impl BIG {
                 u.norm();
                 t.copy(&x1);
                 t.add(p);
-                x1.cmove(&t, (BIG::comp(&x1, &x2) >> 1) & 1);
+                x1.cmove(&t,(BIG::comp(&x1,&x2)>>1)&1);
                 x1.sub(&x2);
                 x1.norm();
             } else {
@@ -799,13 +797,13 @@ impl BIG {
                 v.norm();
                 t.copy(&x2);
                 t.add(p);
-                x2.cmove(&t, (BIG::comp(&x2, &x1) >> 1) & 1);
+                x2.cmove(&t,(BIG::comp(&x2,&x1)>>1)&1);
                 x2.sub(&x1);
                 x2.norm();
             }
         }
         self.copy(&x1);
-        self.cmove(&x2, BIG::comp(&u, &one) & 1);
+        self.cmove(&x2,BIG::comp(&u,&one)&1);
     }
 
     /* return a*b as DBIG - Simple Karatsuba */
@@ -1002,8 +1000,8 @@ impl BIG {
     pub fn modneg(a1: &BIG, m: &BIG) -> BIG {
         let mut a = BIG::new_copy(a1);
         a.rmod(m);
-        a.rsub(m);
-        a.rmod(m);
+	    a.rsub(m);
+	    a.rmod(m);
         a
     }
 
@@ -1013,8 +1011,7 @@ impl BIG {
         let mut b = BIG::new_copy(b1);
         a.rmod(m);
         b.rmod(m);
-        a.add(&b);
-        a.norm();
+        a.add(&b); a.norm();
         a.rmod(m);
         a
     }
