@@ -31,10 +31,11 @@ pub struct FDTYPE {
     pub length: usize,
 }
 
-// Supported Encryption Methods
+// Supported Encryption/Signature Methods
 
 pub const ECC:usize = 1;
 pub const RSA:usize = 2;
+pub const ECD:usize = 3;  // for Ed25519
 
 // Supported Hash functions
 
@@ -71,10 +72,12 @@ const DNS: u8 = 0x82;
 
 // Define some OIDs
 // Elliptic Curve with SHA256
+
 const ECCSHA256:[u8;8]=[0x2a, 0x86, 0x48, 0xce, 0x3d, 0x04, 0x03, 0x02];
 const ECCSHA384:[u8;8]=[0x2a, 0x86, 0x48, 0xce, 0x3d, 0x04, 0x03, 0x03];
 const ECCSHA512:[u8;8]=[0x2a, 0x86, 0x48, 0xce, 0x3d, 0x04, 0x03, 0x04];
 const ECPK:[u8;7]=[0x2a, 0x86, 0x48, 0xce, 0x3d, 0x02, 0x01];
+const EDPK:[u8;3]=[0x2b, 0x65, 0x70];
 const PRIME25519:[u8;9]=[0x2B, 0x06, 0x01, 0x04, 0x01, 0xDA, 0x47, 0x0F, 0x01];
 const PRIME256V1:[u8;8]=[0x2a, 0x86, 0x48, 0xce, 0x3d, 0x03, 0x01, 0x07];
 const SECP384R1:[u8;5]=[0x2B, 0x81, 0x04, 0x00, 0x22];
@@ -207,6 +210,31 @@ pub fn extract_private_key(c: &[u8],pk: &mut [u8]) -> PKTYPE {
         j+=1;
     }
     j=fin;
+
+    if EDPK == soid[0..slen] {
+        len=getalen(OCT,c,j);
+        if len==0 {
+            return ret;
+        }
+        j+=skip(len);
+        len=getalen(OCT,c,j);
+        if len==0 {
+            return ret;
+        }
+        j+=skip(len);
+        let rlen=32;
+        ret.len=rlen;
+        for i in 0..rlen-len {
+            pk[i]=0;
+        }
+        for i in rlen-len..rlen {
+            pk[i]=c[j];
+            j+=1;
+        }
+        ret.kind = ECD;
+        ret.curve = USE_C25519;
+    }
+
     if ECPK == soid[0..slen] {
         len=getalen(OID,c,j);
         if len==0 {
@@ -409,6 +437,10 @@ pub fn extract_cert_sig(sc: &[u8],sig: &mut [u8]) -> PKTYPE {
         j+=1;
 
     }
+    if EDPK == soid[0..slen] {
+        ret.kind=ECD;
+        ret.hash=H512;
+    }
 
     if ECCSHA256 == soid[0..slen] {
         ret.kind=ECC;
@@ -449,6 +481,23 @@ pub fn extract_cert_sig(sc: &[u8],sig: &mut [u8]) -> PKTYPE {
     j+=1;
     len-=1; // skip bit shift (hopefully 0!)
 
+    if ret.kind==ECD {
+        let rlen=bround(len);
+        let ex=rlen-len;
+        ret.len=rlen;
+        slen=0;
+        for _ in 0..ex {
+            sig[slen]=0;
+            slen+=1;
+        }
+        fin=j+len;
+        while j<fin {
+            sig[slen]=sc[j];
+            j+=1;
+            slen+=1;
+        }
+    }
+
     if ret.kind==ECC {
         len=getalen(SEQ,sc,j);
         if len==0 {
@@ -646,6 +695,9 @@ pub fn extract_public_key(c: &[u8],key: &mut [u8]) -> PKTYPE {
     if ECPK == koid[0..slen] {
         ret.kind=ECC;
     }
+    if EDPK == koid[0..slen] {
+        ret.kind=ECD;
+    }
     if RSAPK == koid[0..slen] {
         ret.kind=RSA;
     }
@@ -692,7 +744,7 @@ pub fn extract_public_key(c: &[u8],key: &mut [u8]) -> PKTYPE {
     j+=1;
     len-=1; // skip bit shift (hopefully 0!)
 
-    if ret.kind==ECC {
+    if ret.kind==ECC || ret.kind==ECD {
         ret.len=len;
         fin=j+len;
         slen=0;
